@@ -37,8 +37,28 @@ LILY_EXCLUDE_QUERY_PARSER_ALL_OPTIONAL_ASSERTIONS = getattr(
     'LILY_EXCLUDE_QUERY_PARSER_ALL_OPTIONAL_ASSERTIONS',
     None)
 
-LILY_ANGULAR_CLIENT_ORIGIN = (
-    'git@github.com:cosphere-org/lily-angular-client-base.git')
+LILY_ANGULAR_CLIENT_ORIGIN = getattr(
+    settings,
+    'LILY_ANGULAR_CLIENT_ORIGIN',
+    'https://github.com/cosphere-org/lily-angular-client-base.git')
+
+#
+# TEST
+#
+LILY_TEST_CLIENT_TYPE = getattr(
+    settings,
+    'LILY_TEST_CLIENT_TYPE',
+    'UNIT')
+
+LILY_TEST_CLIENT_VERIFY_SSL = getattr(
+    settings,
+    'LILY_TEST_CLIENT_VERIFY_SSL',
+    False)
+
+LILY_TEST_CLIENT_BASE_URI = getattr(
+    settings,
+    'LILY_TEST_CLIENT_BASE_URI',
+    'http://localhost:8000')
 
 #
 # ASYNC
@@ -94,10 +114,10 @@ DATABASES = {
     'default': {
         'ENGINE': 'django.db.backends.postgresql_psycopg2',
         'NAME': 'lily',
-        'USER': 'local',
-        'PASSWORD': '',
+        'USER': 'lily',
+        'PASSWORD': 'mysecret',
         'HOST': '127.0.0.1',
-        'PORT': '5434',
+        'PORT': '5435',
     },
 }
 
